@@ -13,6 +13,7 @@
 #include <QUrl>
 #include <QString>
 #include <QMetaType>
+#include <QMimeType>
 
 namespace ElisaUtils {
 
@@ -32,6 +33,14 @@ enum PlayListEnqueueTriggerPlay {
 
 Q_ENUM_NS(PlayListEnqueueTriggerPlay)
 
+enum SkipReason {
+    Automatic,  // e.g. song ended
+    Manual,     // e.g. user pressed skip forward button
+
+};
+
+Q_ENUM_NS(SkipReason)
+
 enum PlayListEntryType {
     Album,
     Artist,
@@ -42,6 +51,7 @@ enum PlayListEntryType {
     FileName,
     Container,
     Radio,
+    PlayList,
     Unknown,
 };
 
@@ -61,13 +71,7 @@ enum FilterType {
 
 Q_ENUM_NS(FilterType)
 
-enum IconUseColorOverlay
-{
-    UseColorOverlay = true,
-    DoNotUseColorOverlay = false,
-};
-
-Q_ENUM_NS(IconUseColorOverlay)
+bool isPlayList(const QMimeType& mimeType);
 
 }
 
