@@ -77,12 +77,7 @@ void LocalFileListing::triggerStop()
 
 DataTypes::TrackDataType LocalFileListing::scanOneFile(const QUrl &scanFile, const QFileInfo &scanFileInfo, FileSystemWatchingModes watchForFileSystemChanges)
 {
-    auto trackData = fileScanner().scanOneBalooFile(scanFile, scanFileInfo);
-
-    if (!trackData.isValid()) {
-        qCDebug(orgKdeElisaIndexer()) << "LocalFileListing::scanOneFile" << scanFile << "falling back to plain file metadata analysis";
-        trackData = AbstractFileListing::scanOneFile(scanFile, scanFileInfo, watchForFileSystemChanges);
-    }
+    auto trackData = AbstractFileListing::scanOneFile(scanFile, scanFileInfo, watchForFileSystemChanges);
 
     if (trackData.isValid()) {
         addCover(trackData);
